Flex

Enum Flex 

pub enum Flex {
    Block(u16),
    Grow(u16),
}
Control how much each child of a stack component grows.

For example:

#[component(Root)]
fn render() {
  render! {
    VStack(flex: [1, 2, 3]) {
      Section(title: "small")
      Section(title: "medium")
      Section(title: "large")
    }
  }
}

will render a vertical stack of three Section components. The bottom one will be 3 times the height of the top one, and the middle one will be 2 times the height of the top one, as shown in the VStack docs.

When using the flex parameter to VStack and HStack, providing a value of type [u16; N], will assume that Flex::Grow is intended, therefore making all dimensions relative. In order to have absolute height or width for a child, provide a value of type [Flex; N] to the flex parameter. For example,

#[component(Root)]
fn render() {
  render! {
    VStack(flex: [Block(3), Grow(1), Block(3)]) {
      Section(title: "absolute")
      Section(title: "relative")
      Section(title: "absolute")
    }
  }
}

Variants



Block(u16)

An absolute amount of height or width.



Grow(u16)

A relative amount of height or width.