pub struct HStack<const N: usize> {
pub flex: FlexArray<N>,
pub children: Children<N>,
pub on_key: KeyHandler,
pub on_mouse: MouseHandler,
}Expand description
A component that for renders a horizontal stack of components.
The flex argument specifies the amount of space allocated to each child, similar
to the flex css property. See the FlexArray documentation for details.
An example usage would be,
#[component(Root)]
fn render() {
render! {
HStack(flex: [1, 2, 3]) {
Section(title: "Left")
Section(title: "Middle")
Section(title: "Right")
}
}
}Will render the following:

Fields
flex: FlexArray<N>children: Children<N>on_key: KeyHandleron_mouse: MouseHandlerImplementations